@@ -1,7 +1,7 @@
 try:
     from staticfiles.finders import DefaultStorageFinder
 except ImportError:
-    from django.contrib.staticfiles.storage import DefaultStorageFinder # noqa
+    from django.contrib.staticfiles.finders import DefaultStorageFinder # noqa
 
 from django.conf import settings
 
@@ -29,6 +29,8 @@ class PipelineManifest(Manifest):
         return packages
 
     def cache(self):
+        ignore_patterns = getattr(settings, "STATICFILES_IGNORE_PATTERNS", None)
+        
         if settings.PIPELINE:
             for package in self.packages:
                 yield str(self.packager.individual_url(package.output_filename))
@@ -36,5 +38,5 @@ class PipelineManifest(Manifest):
             for package in self.packages:
                 for path in self.packager.compile(package.paths):
                     yield str(self.packager.individual_url(path))
-        for path in self.finder.list():
+        for path, _ in self.finder.list(ignore_patterns):
             yield str(self.packager.individual_url(path))
